@@ -3,6 +3,7 @@
 
 #include <stdlib.h>
 #include <ctype.h>
+//#include <assert.h>
 #include <errno.h>
 #include <stdio.h>
 #include <string.h>
@@ -10,6 +11,9 @@
 #include "bam.h"
 #include "ksort.h"
 
+
+// All "static" declarations removed (wk)
+
 int g_is_by_qname = 0;
 
 
@@ -67,7 +71,7 @@ void swap_header_text(bam_header_t *h1, bam_header_t *h2)
 {
 	int tempi;
 	char *temps;
-	tempi = (int) h1->l_text, h1->l_text = h2->l_text, h2->l_text = (size_t) tempi;
+	tempi = h1->l_text, h1->l_text = h2->l_text, h2->l_text = tempi;
 	temps = h1->text, h1->text = h2->text, h2->text = temps;
 }
 
@@ -88,14 +92,14 @@ void swap_header_text(bam_header_t *h1, bam_header_t *h2)
   @discussion Padding information may NOT correctly maintained. This
   function is NOT thread safe.
  */
-int bam_merge_core(int by_qname, const char *out, const char *headers, size_t n, char * const *fn,
+int bam_merge_core(int by_qname, const char *out, const char *headers, int n, char * const *fn,
 					int flag, const char *reg)
 {
 	bamFile fpout, *fp;
 	heap1_t *heap;
 	bam_header_t *hout = 0;
 	bam_header_t *hheaders = NULL;
-	int i,j,*RG_len = 0;
+	int i, j, *RG_len = 0;
 	uint64_t idx = 0;
 	char **RG = 0;
 	bam_iter_t *iter = 0;
@@ -119,19 +123,19 @@ int bam_merge_core(int by_qname, const char *out, const char *headers, size_t n,
 	if (flag & MERGE_RG) {
 		RG = (char**)calloc(n, sizeof(void*));
 		RG_len = (int*)calloc(n, sizeof(int));
-		for (i = 0; i != (int)n; ++i) {
-			int l = (int) strlen(fn[i]);
+		for (i = 0; i != n; ++i) {
+			int l = strlen(fn[i]);
 			const char *s = fn[i];
 			if (l > 4 && strcmp(s + l - 4, ".bam") == 0) l -= 4;
 			for (j = l - 1; j >= 0; --j) if (s[j] == '/') break;
 			++j; l -= j;
-			RG[i] = calloc((size_t) l + 1, 1);
-			RG_len[i] = (int) l;
-			strncpy(RG[i], s + j, (size_t) l);
+			RG[i] = calloc(l + 1, 1);
+			RG_len[i] = l;
+			strncpy(RG[i], s + j, l);
 		}
 	}
 	// read the first
-	for (i = 0; i != (int) n; ++i) {
+	for (i = 0; i != n; ++i) {
 		bam_header_t *hin;
 		fp[i] = bam_open(fn[i], "r");
 		if (fp[i] == 0) {
@@ -193,7 +197,7 @@ int bam_merge_core(int by_qname, const char *out, const char *headers, size_t n,
 			Rprintf("[%s] Malformated region string or undefined reference name\n", __func__);
 			return -1;
 		}
-		for (i = 0; i < (int) n; ++i) {
+		for (i = 0; i < n; ++i) {
 			bam_index_t *idx;
 			idx = bam_index_load(fn[i]);
 			iter[i] = bam_iter_query(idx, tid, beg, end);
@@ -201,7 +205,7 @@ int bam_merge_core(int by_qname, const char *out, const char *headers, size_t n,
 		}
 	}
 
-	for (i = 0; i < (int) n; ++i) {
+	for (i = 0; i < n; ++i) {
 		heap1_t *h = heap + i;
 		h->i = i;
 		h->b = (bam1_t*)calloc(1, sizeof(bam1_t));
@@ -244,10 +248,10 @@ int bam_merge_core(int by_qname, const char *out, const char *headers, size_t n,
 	}
 
 	if (flag & MERGE_RG) {
-		for (i = 0; i != (int) n; ++i) free(RG[i]);
+		for (i = 0; i != n; ++i) free(RG[i]);
 		free(RG); free(RG_len);
 	}
-	for (i = 0; i != (int) n; ++i) {
+	for (i = 0; i != n; ++i) {
 		bam_iter_destroy(iter[i]);
 		bam_close(fp[i]);
 	}
@@ -256,63 +260,6 @@ int bam_merge_core(int by_qname, const char *out, const char *headers, size_t n,
 	return 0;
 }
 
-int bam_merge(int argc, char *argv[])
-{
-	int c, is_by_qname = 0, flag = 0, ret = 0;
-	char *fn_headers = NULL, *reg = 0;
-	size_t len;
-
-	while ((c = getopt(argc, argv, "h:nru1R:f")) >= 0) {
-		switch (c) {
-		case 'r': flag |= MERGE_RG; break;
-		case 'f': flag |= MERGE_FORCE; break;
-		case 'h':
-			//fn_headers = str_dup(optarg); break;
-			len = strlen(optarg) + 1;
-			fn_headers = malloc(len);
-			memcpy(fn_headers,optarg,len);
-			break;
-
-		case 'n': is_by_qname = 1; break;
-		case '1': flag |= MERGE_LEVEL1; break;
-		case 'u': flag |= MERGE_UNCOMP; break;
-		case 'R':
-			//reg = str_dup(optarg); break;
-			len = strlen(optarg) + 1;
-			reg = malloc(len);
-			memcpy(reg,optarg,len);
-			break;
-		}
-	}
-	if (optind + 2 >= argc) {
-		Rprintf("\n");
-		Rprintf("Usage:   samtools merge [-nr] [-h inh.sam] <out.bam> <in1.bam> <in2.bam> [...]\n\n");
-		Rprintf("Options: -n       sort by read names\n");
-		Rprintf("         -r       attach RG tag (inferred from file names)\n");
-		Rprintf("         -u       uncompressed BAM output\n");
-		Rprintf("         -f       overwrite the output BAM if exist\n");
-		Rprintf("         -1       compress level 1\n");
-		Rprintf("         -R STR   merge file in the specified region STR [all]\n");
-		Rprintf("         -h FILE  copy the header in FILE to <out.bam> [in1.bam]\n\n");
-		Rprintf("Note: Samtools' merge does not reconstruct the @RG dictionary in the header. Users\n");
-		Rprintf("      must provide the correct header with -h, or uses Picard which properly maintains\n");
-		Rprintf("      the header dictionary in merging.\n\n");
-		return 1;
-	}
-	if (!(flag & MERGE_FORCE) && strcmp(argv[optind], "-")) {
-		FILE *fp = fopen(argv[optind], "rb");
-		if (fp != NULL) {
-			fclose(fp);
-			// REP: fprintf(stderr, "[%s] File '%s' exists. Please apply '-f' to overwrite. Abort.\n", __func__, argv[optind]);
-			Rprintf("[%s] File '%s' exists. Please apply '-f' to overwrite. Abort.\n", __func__, argv[optind]);
-			return 1;
-		}
-	}
-	if (bam_merge_core(is_by_qname, argv[optind], fn_headers, argc - optind - 1, argv + optind + 1, flag, reg) < 0) ret = 1;
-	free(reg);
-	free(fn_headers);
-	return ret;
-}
 
 typedef bam1_t *bam1_p;
 
@@ -320,8 +267,8 @@ static R_INLINE int bam1_lt(const bam1_p a, const bam1_p b)
 {
 	if (g_is_by_qname) {
 		int t = strnum_cmp(bam1_qname(a), bam1_qname(b));
-		return (t < 0 || (t == 0 && (((uint64_t)a->core.tid<<32|((uint64_t)a->core.pos+1)) < ((uint64_t)b->core.tid<<32|((uint64_t)b->core.pos+1)))));
-	} else return (((uint64_t)a->core.tid<<32|((uint64_t)a->core.pos+1)) < ((uint64_t)b->core.tid<<32|((uint64_t)b->core.pos+1)));
+		return (t < 0 || (t == 0 && (((uint64_t)a->core.tid<<32|(a->core.pos+1)) < ((uint64_t)b->core.tid<<32|(b->core.pos+1)))));
+	} else return (((uint64_t)a->core.tid<<32|(a->core.pos+1)) < ((uint64_t)b->core.tid<<32|(b->core.pos+1)));
 }
 KSORT_INIT(sort, bam1_p, bam1_lt)
 
@@ -330,7 +277,7 @@ void sort_blocks(int n, int k, bam1_p *buf, const char *prefix, const bam_header
 	char *name, mode[3];
 	int i;
 	bamFile fp;
-	ks_mergesort(sort, ((size_t) k), buf, 0);
+	ks_mergesort(sort, k, buf, 0);
 	name = (char*)calloc(strlen(prefix) + 20, 1);
 	if (n >= 0) {
 		sprintf(name, "%s.%.4d.bam", prefix, n);
@@ -339,13 +286,11 @@ void sort_blocks(int n, int k, bam1_p *buf, const char *prefix, const bam_header
 		sprintf(name, "%s.bam", prefix);
 		strcpy(mode, "w");
 	}
-
-	if(is_stdout)
-		error("[sort_blocks.bam_sort.c] Output to stdout is not supported.");
 	fp = bam_open(name, mode);
 	if (fp == 0) {
 		Rprintf("[sort_blocks] fail to create file %s.\n", name);
 		free(name);
+		// FIXME: possible memory leak
 		return;
 	}
 	free(name);
@@ -371,15 +316,14 @@ void sort_blocks(int n, int k, bam1_p *buf, const char *prefix, const bam_header
  */
 void bam_sort_core_ext(int is_by_qname, const char *fn, const char *prefix, size_t max_mem, int is_stdout)
 {
-	int ret, k, i;
-	size_t mem, n;
+	int n, ret, k, i;
+	size_t mem;
 	bam_header_t *header;
 	bamFile fp;
 	bam1_t *b, **buf;
 
 	g_is_by_qname = is_by_qname;
-	n = 0;
-	k = 0; mem = 0;
+	n = k = 0; mem = 0;
 	fp = bam_open(fn, "r");
 	if (fp == 0) {
 		Rprintf("[bam_sort_core_ext] fail to open file %s\n", fn);
@@ -392,43 +336,39 @@ void bam_sort_core_ext(int is_by_qname, const char *fn, const char *prefix, size
 		if (buf[k] == 0) buf[k] = bam_init1();
 		b = buf[k];
 		if ((ret = bam_read1(fp, b)) < 0) break;
-		mem += (size_t) ret;
+		mem += ret;
 		++k;
 		if (mem >= max_mem) {
-			sort_blocks((int)(n++), k, buf, prefix, header, 0);
+			sort_blocks(n++, k, buf, prefix, header, 0);
 			mem = 0; k = 0;
 		}
 	}
 	if (ret != -1)
 		Rprintf("[bam_sort_core_ext] truncated file. Continue anyway.\n");
-
 	if (n == 0) sort_blocks(-1, k, buf, prefix, header, is_stdout);
 	else { // then merge
 		char **fns, *fnout;
-
-		Rprintf("[bam_sort_core_ext] merging from %lu files...\n", n+1);
-		sort_blocks( (int) (n++), k, buf, prefix, header, 0);
+		Rprintf("[bam_sort_core_ext] merging from %d files...\n", n+1);
+		sort_blocks(n++, k, buf, prefix, header, 0);
 		fnout = (char*)calloc(strlen(prefix) + 20, 1);
 
 		sprintf(fnout, "%s.bam", prefix);
 		fns = (char**)calloc(n, sizeof(char*));
-		for (i = 0; i < (int) n; ++i) {
+		for (i = 0; i < n; ++i) {
 			fns[i] = (char*)calloc(strlen(prefix) + 20, 1);
 			sprintf(fns[i], "%s.%.4d.bam", prefix, i);
 		}
 		bam_merge_core(is_by_qname, fnout, 0, n, fns, 0, 0);
 		free(fnout);
-		for (i = 0; i < (int) n; ++i) {
+		for (i = 0; i < n; ++i) {
 			unlink(fns[i]);
 			free(fns[i]);
 		}
 		free(fns);
 	}
-	for (k = 0; k < ((int)(max_mem / BAM_CORE_SIZE)); ++k) {
+	for (k = 0; k < max_mem / BAM_CORE_SIZE; ++k) {
 		if (buf[k]) {
 			bam_destroy1(buf[k]);
-			//free(buf[k]->data);
-			//free(buf[k]);
 		}
 	}
 	free(buf);
@@ -440,5 +380,4 @@ void bam_sort_core(int is_by_qname, const char *fn, const char *prefix, size_t m
 {
 	bam_sort_core_ext(is_by_qname, fn, prefix, max_mem, 0);
 }
-
 #endif
