@@ -141,13 +141,13 @@ static int tag_exists(const char *tag, const char **tags)
 //  newline character is stripped.
 static const char *nextline(char **lineptr, size_t *n, const char *text)
 {
-    size_t len;
+    int len;
     const char *to = text;
 
     if ( !*to ) return NULL;
 
     while ( *to && *to!='\n' && *to!='\r' ) to++;
-    len = (size_t) (to - text + 1);
+    len = to - text + 1;
 
     if ( *to )
     {
@@ -184,7 +184,7 @@ static const char *nextline(char **lineptr, size_t *n, const char *text)
 static HeaderTag *new_tag(const char *name, const char *value_from, const char *value_to)
 {
     HeaderTag *tag = malloc(sizeof(HeaderTag));
-    size_t len = (size_t) (value_to-value_from+1);
+    int len = value_to-value_from+1;
 
     tag->key[0] = name[0];
     tag->key[1] = name[1];
@@ -289,7 +289,6 @@ static int sam_header_compare_lines(HeaderLine *hline1, HeaderLine *hline2)
 
 static HeaderLine *sam_header_line_clone(const HeaderLine *hline)
 {
-	size_t len;
     list_t *tags;
     HeaderLine *out = malloc(sizeof(HeaderLine));
     out->type[0] = hline->type[0];
@@ -304,11 +303,8 @@ static HeaderLine *sam_header_line_clone(const HeaderLine *hline)
         HeaderTag *new = malloc(sizeof(HeaderTag));
         new->key[0] = old->key[0];
         new->key[1] = old->key[1];
-
-        //new->value  = str_dup(old->value);
-        len = strlen(old->value) + 1;
-        new->value = malloc(len);
-        memcpy(new->value,old->value,len);
+        new->value = malloc(strlen(old->value) + 1);
+        strcpy(new->value,old->value);
 
         out->tags = list_append(out->tags, new);
 
@@ -320,7 +316,6 @@ static HeaderLine *sam_header_line_clone(const HeaderLine *hline)
 static int sam_header_line_merge_with(HeaderLine *out_hline, const HeaderLine *tmpl_hline)
 {
     list_t *tmpl_tags;
-    size_t len;
 
     if ( out_hline->type[0]!=tmpl_hline->type[0] || out_hline->type[1]!=tmpl_hline->type[1] )
         return 0;
@@ -335,11 +330,8 @@ static int sam_header_line_merge_with(HeaderLine *out_hline, const HeaderLine *t
             HeaderTag *tag = malloc(sizeof(HeaderTag));
             tag->key[0] = tmpl_tag->key[0];
             tag->key[1] = tmpl_tag->key[1];
-
-            //tag->value  = str_dup(tmpl_tag->value);
-            len = strlen(tmpl_tag->value) + 1;
-            tag->value = malloc(len);
-            memcpy(tag->value,tmpl_tag->value,len);
+            tag->value  = malloc(strlen(tmpl_tag->value) + 1);
+            strcpy(tag->value,tmpl_tag->value);
 
             out_hline->tags = list_append(out_hline->tags,tag);
         }
@@ -456,27 +448,6 @@ static int sam_header_line_validate(HeaderLine *hline)
     return 1;
 }
 
-/*
-static void print_header_line(FILE *fp, HeaderLine *hline)
-{
-    list_t *tags = hline->tags;
-    HeaderTag *tag;
-
-    fprintf(fp, "@%c%c", hline->type[0],hline->type[1]);
-    while (tags)
-    {
-        tag = tags->data;
-
-        fprintf(fp, "\t");
-        if ( tag->key[0]!=' ' || tag->key[1]!=' ' )
-            fprintf(fp, "%c%c:", tag->key[0],tag->key[1]);
-        fprintf(fp, "%s", tag->value);
-
-        tags = tags->next;
-    }
-    fprintf(fp,"\n");
-}
-*/
 static void print_header_line(HeaderLine *hline)
 {
     list_t *tags = hline->tags;
@@ -541,8 +512,7 @@ char *sam_header_write(const void *_header)
 {
 	const HeaderDict *header = (const HeaderDict*)_header;
     char *out = NULL;
-    int nout=0;
-    size_t len=0;
+    int len=0, nout=0;
     const list_t *hlines;
 
     // Calculate the length of the string to allocate
@@ -570,7 +540,6 @@ char *sam_header_write(const void *_header)
     while (hlines)
     {
         HeaderLine *hline = hlines->data;
-
         nout += sprintf(out+nout,"@%c%c",hline->type[0],hline->type[1]);
 
         list_t *tags = hline->tags;
@@ -664,12 +633,10 @@ char **sam_header2list(const void *_dict, char type[2], char key_tag[2], int *_n
 {
 	const HeaderDict *dict = (const HeaderDict*)_dict;
     const list_t *l   = dict;
-    size_t max, n;
+    int max, n;
 	char **ret;
 
-	ret = 0;
-	max = n = 0;
-	*_n = (int) max;
+	ret = 0; *_n = max = n = 0;
     while (l)
     {
         HeaderLine *hline = l->data;
@@ -695,7 +662,7 @@ char **sam_header2list(const void *_dict, char type[2], char key_tag[2], int *_n
 
         l = l->next;
     }
-	*_n = (int) n;
+	*_n = n;
     return ret;
 }
 
@@ -748,8 +715,6 @@ void *sam_header_merge(int n, const void **_dicts)
                 
                 if ( status==2 ) 
                 {
-                    //print_header_line(stderr,tmpl_hlines->data);
-                    //print_header_line(stderr,out_hlines->data);
                     print_header_line(tmpl_hlines->data);
                     print_header_line(out_hlines->data);
                     debug("Conflicting lines, cannot merge the headers.\n");
@@ -767,7 +732,6 @@ void *sam_header_merge(int n, const void **_dicts)
             tmpl_hlines = tmpl_hlines->next;
         }
     }
-
     return out_dict;
 }
 
